@@ -5,7 +5,7 @@ library(rly)
 
 context("Return a bad token name")
 
-Lexer <- R6Class("Lexer",
+Lexer <- R6::R6Class("Lexer",
   public = list(
     tokens = c('NUMBER', 'PLUS', 'MINUS'),
     t_PLUS = '\\+',
